package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public final class ConstantMethodHandle extends Constant
{
    private int referenceKind;
    private int referenceIndex;
    
    public ConstantMethodHandle(final ConstantMethodHandle c) {
        this(c.getReferenceKind(), c.getReferenceIndex());
    }
    
    ConstantMethodHandle(final DataInput file) throws IOException {
        this(file.readUnsignedByte(), file.readUnsignedShort());
    }
    
    public ConstantMethodHandle(final int referenceKind, final int referenceIndex) {
        super((byte)15);
        this.referenceKind = referenceKind;
        this.referenceIndex = referenceIndex;
    }
    
    @Override
    public void accept(final Visitor v) {
        v.visitConstantMethodHandle(this);
    }
    
    @Override
    public void dump(final DataOutputStream file) throws IOException {
        file.writeByte(super.getTag());
        file.writeByte(this.referenceKind);
        file.writeShort(this.referenceIndex);
    }
    
    public int getReferenceIndex() {
        return this.referenceIndex;
    }
    
    public int getReferenceKind() {
        return this.referenceKind;
    }
    
    public void setReferenceIndex(final int referenceIndex) {
        this.referenceIndex = referenceIndex;
    }
    
    public void setReferenceKind(final int referenceKind) {
        this.referenceKind = referenceKind;
    }
    
    @Override
    public String toString() {
        return super.toString() + "(referenceKind = " + this.referenceKind + ", referenceIndex = " + this.referenceIndex + ")";
    }
}
